@@ -15,14 +15,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import threading
-from robotframework_debug_adapter.constants import DEBUG
 from functools import partial
-import itertools
+from robocode_ls_core.robotframework_log import get_logger
+from robotframework_debug_adapter.constants import DEBUG
 from robotframework_ls.options import DEFAULT_TIMEOUT
+import itertools
 import json
 import os.path
-from robotframework_ls.robotframework_log import get_logger
+import threading
 
 try:
     import Queue as queue
@@ -32,13 +32,22 @@ except ImportError:
 log = get_logger(__name__)
 
 
-class _DebugAdapterComm(threading.Thread):
+class _DebugAdapterRobotTargetComm(threading.Thread):
     """
-    This class is used so intermediate talking to the server (which should actually
-    be communicating using the debug adapter protocol).
+    This class is used so intermediate talking to the server.
+    
+    It's the middle ground between the `DebugAdapterComm` and `RobotTargetComm`.
+        - `DebugAdapterComm`:
+            It's used to talk with the client (in this process) and accessed
+            through the _weak_debug_adapter_comm attribute.
+             
+        - `RobotTargetComm`
+            It's actually in the target process. We communicate with it by 
+            calling the `write_to_robot_message` method and receive messages
+            from it in the `_from_robot` method in this class.
     """
 
-    def __init__(self, command_processor):
+    def __init__(self, debug_adapter_comm):
         threading.Thread.__init__(self)
         import weakref
 
@@ -51,8 +60,11 @@ class _DebugAdapterComm(threading.Thread):
         self._terminated_event_msg = None
         self._terminated_event = threading.Event()
 
-        self._write_queue = queue.Queue()
-        self._weak_command_processor = weakref.ref(command_processor)
+        self._write_to_robot_queue = queue.Queue()
+        self._weak_debug_adapter_comm = weakref.ref(debug_adapter_comm)
+
+        self._next_seq = partial(next, itertools.count(0))
+        self._msg_id_to_on_response = {}
 
     def start_listening(self):
         import socket
@@ -67,7 +79,9 @@ class _DebugAdapterComm(threading.Thread):
         return port
 
     def run(self):
-        from robotframework_debug_adapter.debug_adapter_threads import writer_thread
+        from robotframework_debug_adapter.debug_adapter_threads import (
+            writer_thread_no_auto_seq,
+        )
         from robotframework_debug_adapter.debug_adapter_threads import reader_thread
 
         try:
@@ -83,8 +97,8 @@ class _DebugAdapterComm(threading.Thread):
             write_to = socket.makefile("wb")
 
             writer = self._writer_thread = threading.Thread(
-                target=writer_thread,
-                args=(write_to, self._write_queue, "write to robot process"),
+                target=writer_thread_no_auto_seq,
+                args=(write_to, self._write_to_robot_queue, "write to robot process"),
                 name="Write to robot",
             )
             writer.daemon = True
@@ -93,8 +107,8 @@ class _DebugAdapterComm(threading.Thread):
                 target=reader_thread,
                 args=(
                     read_from,
-                    self._process_command,
-                    self._write_queue,
+                    self._from_robot,
+                    self._write_to_robot_queue,  # Used for errors
                     b"read from robot process",
                 ),
                 name="Read from robot",
@@ -108,7 +122,7 @@ class _DebugAdapterComm(threading.Thread):
         except:
             log.exception()
 
-    def _process_command(self, protocol_message):
+    def _from_robot(self, protocol_message):
         from robotframework_debug_adapter.debug_adapter_threads import (
             READER_THREAD_STOPPED,
         )
@@ -116,7 +130,8 @@ class _DebugAdapterComm(threading.Thread):
         if protocol_message is READER_THREAD_STOPPED:
             if DEBUG:
                 log.debug(
-                    "_DebugAdapterComm when reading from robot: READER_THREAD_STOPPED."
+                    "%s when reading from robot: READER_THREAD_STOPPED."
+                    % (self.__class__.__name__,)
                 )
             return
 
@@ -127,26 +142,38 @@ class _DebugAdapterComm(threading.Thread):
             )
 
         try:
+            on_response = None
             if protocol_message.type == "request":
                 method_name = "on_%s_request" % (protocol_message.command,)
             elif protocol_message.type == "event":
                 method_name = "on_%s_event" % (protocol_message.event,)
+            elif protocol_message.type == "response":
+                on_response = self._msg_id_to_on_response.pop(
+                    protocol_message.request_seq, None
+                )
+                method_name = "on_%s_response" % (protocol_message.command,)
             else:
                 if DEBUG:
                     log.debug(
-                        "Unable to decide how to deal with protocol type: %s (read from robot - _DebugAdapterComm).\n"
-                        % (protocol_message.type,)
+                        "Unable to decide how to deal with protocol type: %s (read from robot - %s).\n"
+                        % (protocol_message.type, self.__class__.__name__)
                     )
                 return
 
+            if on_response is not None:
+                on_response(protocol_message)
+
             on_request = getattr(self, method_name, None)
+
             if on_request is not None:
                 on_request(protocol_message)
+            elif on_response is not None:
+                pass
             else:
                 if DEBUG:
                     log.debug(
-                        "Unhandled: %s not available when reading from robot - _DebugAdapterComm.\n"
-                        % (method_name,)
+                        "Unhandled: %s not available when reading from robot - %s.\n"
+                        % (method_name, self.__class__.__name__)
                     )
         except:
             log.exception("Error")
@@ -159,20 +186,30 @@ class _DebugAdapterComm(threading.Thread):
         assert self._process_event.is_set()
         return self._process_event_msg.body.systemProcessId
 
+    def on_stopped_event(self, event):
+        debug_adapter_comm = self._weak_debug_adapter_comm()
+        if debug_adapter_comm is not None:
+            debug_adapter_comm.write_to_client_message(event)
+        else:
+            log.debug("Command processor collected in event: %s" % (event,))
+
     def on_terminated_event(self, event):
         from robotframework_debug_adapter.dap.dap_schema import TerminatedEvent
         from robotframework_debug_adapter.dap.dap_schema import TerminatedEventBody
 
         self._terminated_event_msg = event
         self._terminated_event.set()
-        self.write_message(TerminatedEvent(TerminatedEventBody()))
+        self.write_to_robot_message(TerminatedEvent(TerminatedEventBody()))
 
-    def write_message(self, protocol_message):
+    def write_to_robot_message(self, protocol_message, on_response=None):
         """
         :param BaseSchema protocol_message:
             Some instance of one of the messages in the debug_adapter.schema.
         """
-        self._write_queue.put(protocol_message)
+        seq = protocol_message.seq = self._next_seq()
+        if on_response is not None:
+            self._msg_id_to_on_response[seq] = on_response
+        self._write_to_robot_queue.put(protocol_message)
 
     def wait_for_connection(self):
         """
@@ -214,7 +251,7 @@ def _read_stream(stream, on_line, category):
 
 def _notify_on_exited_pid(on_exit, pid):
     try:
-        from robotframework_ls._utils import is_process_alive
+        from robocode_ls_core.basic import is_process_alive
         import time
 
         log.debug("Waiting for pid to exit (_notify_on_exited_pid).")
@@ -237,11 +274,11 @@ class LaunchProcess(object):
         "_cmdline",
         "_terminal",
         "_popen",
-        "_weak_command_processor",
+        "_weak_debug_adapter_comm",
         "__weakref__",
         "_cwd",
         "_run_in_debug_mode",
-        "_debug_adapter_comm",
+        "_debug_adapter_robot_target_comm",
         "_launch_response",
         "_next_seq",
         "_track_process_pid",
@@ -249,7 +286,7 @@ class LaunchProcess(object):
         "_env",
     ]
 
-    def __init__(self, request, launch_response, command_processor):
+    def __init__(self, request, launch_response, debug_adapter_comm):
         """
         :param LaunchRequest request:
         :param LaunchResponse launch_response:
@@ -257,9 +294,10 @@ class LaunchProcess(object):
         import weakref
         from robotframework_debug_adapter.constants import VALID_TERMINAL_OPTIONS
         from robotframework_debug_adapter.constants import TERMINAL_NONE
-        from robotframework_ls._utils import as_str
+        from robocode_ls_core.basic import as_str
+        import robocode_ls_core
 
-        self._weak_command_processor = weakref.ref(command_processor)
+        self._weak_debug_adapter_comm = weakref.ref(debug_adapter_comm)
         self._valid = True
         self._cmdline = []
         self._popen = None
@@ -268,7 +306,9 @@ class LaunchProcess(object):
         self._track_process_pid = None
         self._sent_terminated = threading.Event()
 
-        self._debug_adapter_comm = _DebugAdapterComm(command_processor)
+        self._debug_adapter_robot_target_comm = _DebugAdapterRobotTargetComm(
+            debug_adapter_comm
+        )
 
         def mark_invalid(message):
             launch_response.success = False
@@ -289,7 +329,12 @@ class LaunchProcess(object):
             env.update(request_env)
 
         pythonpath = env.get("PYTHONPATH", "")
-        pythonpath += os.pathsep + os.path.dirname(os.path.dirname(__file__))
+        pythonpath += (
+            os.pathsep
+            + os.path.dirname(os.path.dirname(__file__))
+            + os.pathsep
+            + os.path.dirname(os.path.dirname(robocode_ls_core.__file__))
+        )
         env["PYTHONPATH"] = pythonpath
 
         for key, value in os.environ.items():
@@ -300,9 +345,7 @@ class LaunchProcess(object):
 
         self._env = env
 
-        # TODO: Right now we can't debug, just run as usual.
-        # self._run_in_debug_mode = not request.arguments.noDebug
-        self._run_in_debug_mode = False
+        self._run_in_debug_mode = not request.arguments.noDebug
 
         if self._terminal not in VALID_TERMINAL_OPTIONS:
             return mark_invalid(
@@ -333,7 +376,7 @@ class LaunchProcess(object):
         if DEBUG:
             log.debug("Run in debug mode: %s\n" % (self._run_in_debug_mode,))
 
-        port = self._debug_adapter_comm.start_listening()
+        port = self._debug_adapter_robot_target_comm.start_listening()
 
         try:
             run_robot_py = os.path.join(
@@ -345,13 +388,17 @@ class LaunchProcess(object):
             log.exception("Error")
             return mark_invalid("Error checking if run_robot__main__.py exists.")
 
-        if self._run_in_debug_mode:
-            raise AssertionError("Running in debug mode is currently not supported.")
-
         else:
             # Note: target must be the last parameter.
             cmdline = (
-                [sys.executable, "-u", run_robot_py, "--port", str(port)]
+                [
+                    sys.executable,
+                    "-u",
+                    run_robot_py,
+                    "--port",
+                    str(port),
+                    "--debug" if self._run_in_debug_mode else "--no-debug",
+                ]
                 + args
                 + [target]
             )
@@ -373,13 +420,49 @@ class LaunchProcess(object):
         from robotframework_debug_adapter.dap.dap_schema import TerminatedEvent
         from robotframework_debug_adapter.dap.dap_schema import TerminatedEventBody
 
-        command_processor = self._weak_command_processor()
-        if command_processor is not None:
+        debug_adapter_comm = self._weak_debug_adapter_comm()
+        if debug_adapter_comm is not None:
             restart = False
             terminated_event = TerminatedEvent(
                 body=TerminatedEventBody(restart=restart)
             )
-            command_processor.write_message(terminated_event)
+            debug_adapter_comm.write_to_client_message(terminated_event)
+
+    def send_and_wait_for_configuration_done_request(self):
+        from robotframework_debug_adapter.dap.dap_schema import ConfigurationDoneRequest
+        from robotframework_debug_adapter.dap.dap_schema import (
+            ConfigurationDoneArguments,
+        )
+
+        event = threading.Event()
+        self._debug_adapter_robot_target_comm.write_to_robot_message(
+            ConfigurationDoneRequest(ConfigurationDoneArguments()),
+            on_response=lambda *args, **kwargs: event.set(),
+        )
+        log.debug(
+            "Wating for configuration_done response for %s seconds."
+            % (DEFAULT_TIMEOUT,)
+        )
+        ret = event.wait(DEFAULT_TIMEOUT)
+        log.debug("Received configuration_done response: %s" % (ret,))
+        return ret
+
+    def resend_request_to_robot(self, request):
+        request_seq = request.seq
+
+        def on_response(response_msg):
+            response_msg.request_seq = request_seq
+            debug_adapter_comm = self._weak_debug_adapter_comm()
+            if debug_adapter_comm is not None:
+                debug_adapter_comm.write_to_client_message(response_msg)
+            else:
+                log.debug(
+                    "Command processor collected in resend request: %s" % (request,)
+                )
+
+        self._debug_adapter_robot_target_comm.write_to_robot_message(
+            request, on_response
+        )
 
     def launch(self):
         from robotframework_debug_adapter.constants import TERMINAL_NONE
@@ -395,16 +478,12 @@ class LaunchProcess(object):
         from robotframework_debug_adapter.dap.dap_schema import (
             InitializeRequestArguments,
         )
-        from robotframework_debug_adapter.dap.dap_schema import ConfigurationDoneRequest
-        from robotframework_debug_adapter.dap.dap_schema import (
-            ConfigurationDoneArguments,
-        )
 
         # Note: using a weak-reference so that callbacks don't keep it alive
-        weak_command_processor = self._weak_command_processor
+        weak_debug_adapter_comm = self._weak_debug_adapter_comm
 
         terminal = self._terminal
-        if not weak_command_processor().supports_run_in_terminal:
+        if not weak_debug_adapter_comm().supports_run_in_terminal:
             # If the client doesn't support running in the terminal we fallback to using the debug console.
             terminal = TERMINAL_NONE
 
@@ -430,12 +509,12 @@ class LaunchProcess(object):
             )
 
             def on_output(output, category):
-                command_processor = weak_command_processor()
-                if command_processor is not None:
+                debug_adapter_comm = weak_debug_adapter_comm()
+                if debug_adapter_comm is not None:
                     output_event = OutputEvent(
                         OutputEventBody(output, category=category)
                     )
-                    command_processor.write_message(output_event)
+                    debug_adapter_comm.write_to_client_message(output_event)
 
             stdout_stream_thread = threading.Thread(
                 target=_read_stream,
@@ -457,9 +536,9 @@ class LaunchProcess(object):
             if DEBUG:
                 log.debug('Launching in "%s" terminal: %s' % (kind, self._cmdline))
 
-            command_processor = weak_command_processor()
-            if command_processor is not None:
-                command_processor.write_message(
+            debug_adapter_comm = weak_debug_adapter_comm()
+            if debug_adapter_comm is not None:
+                debug_adapter_comm.write_to_client_message(
                     RunInTerminalRequest(
                         RunInTerminalRequestArguments(
                             cwd=self._cwd, args=self._cmdline, kind=kind, env=self._env
@@ -470,25 +549,22 @@ class LaunchProcess(object):
         for t in threads:
             t.daemon = True
 
-        if not self._debug_adapter_comm.wait_for_connection():
+        if not self._debug_adapter_robot_target_comm.wait_for_connection():
             launch_response = self._launch_response
             launch_response.success = False
             launch_response.message = "Debug adapter timed out waiting for connection."
             self._valid = False
 
-        self._debug_adapter_comm.write_message(
+        self._debug_adapter_robot_target_comm.write_to_robot_message(
             InitializeRequest(
                 InitializeRequestArguments("robot-launch-process-adapter")
             )
         )
-        self._debug_adapter_comm.write_message(
-            ConfigurationDoneRequest(ConfigurationDoneArguments())
-        )
         # Note: only start listening stdout/stderr when connected.
         for t in threads:
             t.start()
 
-        if not self._debug_adapter_comm.wait_for_process_event():
+        if not self._debug_adapter_robot_target_comm.wait_for_process_event():
             launch_response = self._launch_response
             launch_response.success = False
             launch_response.message = (
@@ -496,7 +572,7 @@ class LaunchProcess(object):
             )
             self._valid = False
         else:
-            self._track_process_pid = self._debug_adapter_comm.get_pid()
+            self._track_process_pid = self._debug_adapter_robot_target_comm.get_pid()
 
     def after_launch_response_sent(self):
         if self._track_process_pid is None:
@@ -511,7 +587,7 @@ class LaunchProcess(object):
         t.start()
 
     def disconnect(self, disconnect_request):
-        from robotframework_ls._utils import kill_process_and_subprocesses
+        from robocode_ls_core.basic import kill_process_and_subprocesses
 
         if self._popen is not None:
             if self._popen.returncode is None:
