@@ -1,64 +1,9 @@
-import re
 from robotframework_ls.impl.robot_workspace import RobotDocument
-from robotframework_ls.cache import instance_cache
-from robotframework_ls.robotframework_log import get_logger
+from robocode_ls_core.cache import instance_cache
+from robocode_ls_core.robotframework_log import get_logger
 
 log = get_logger(__name__)
 
-# TODO: this is not the best e.g. we capture numbers
-RE_START_WORD = re.compile("[A-Za-z_0-9]*$")
-RE_END_WORD = re.compile("^[A-Za-z_0-9]*")
-
-
-class DocumentSelection(object):
-    def __init__(self, doc, line, col):
-        self.doc = doc
-        self.line = line
-        self.col = col
-
-    @property
-    def offset_at_position(self):
-        """Return the byte-offset pointed at by the given position."""
-        offset = 0
-        for i, curr_line in enumerate(self.doc.iter_lines()):
-            if i == self.line:
-                break
-            offset += len(curr_line)
-
-        return offset + self.col
-
-    @property
-    def current_line(self):
-        return self.doc.get_line(self.line)
-
-    @property
-    def line_to_column(self):
-        current_line = self.current_line
-        if not current_line:
-            return ""
-        line_start = current_line[: self.col]
-
-        return line_start
-
-    @property
-    def word_at_position(self):
-        """Get the word under the cursor returning the start and end positions."""
-        current_line = self.current_line
-        if not current_line:
-            return ""
-
-        col = self.col
-        # Split word in two
-        start = current_line[:col]
-        end = current_line[col:]
-
-        # Take end of start and start of end to find word
-        # These are guaranteed to match, even if they match the empty string
-        m_start = RE_START_WORD.findall(start)
-        m_end = RE_END_WORD.findall(end)
-
-        return m_start[0] + m_end[-1]
-
 
 _NOT_SET = "NOT_SET"
 
@@ -101,11 +46,11 @@ class CompletionContext(object):
         self, doc, line=_NOT_SET, col=_NOT_SET, workspace=None, config=None, memo=None
     ):
         """
-        :param robotframework_ls.workspace.Document doc:
+        :param robocode_ls_core.workspace.Document doc:
         :param int line:
         :param int col:
         :param RobotWorkspace workspace:
-        :param robotframework_ls.config.config.Config config:
+        :param robocode_ls_core.config.Config config:
         :param _Memo memo:
         """
 
@@ -305,7 +250,7 @@ class CompletionContext(object):
 
     @instance_cache
     def iter_imports_docs(self):
-        from robotframework_ls import uris
+        from robocode_ls_core import uris
         import os.path
         from robotframework_ls.impl import ast_utils
 
