@@ -2,6 +2,9 @@
 Constants that help in describing the accepted structure of a file.
 """
 
+BDD_PREFIXES = ["given ", "when ", "then ", "and ", "but "]
+VARIABLE_PREFIXES = ("@", "%", "$", "&")
+
 
 class Section(object):
 
