@@ -13,10 +13,5 @@ OPTION_ROBOT_COMPLETION_SECTION_HEADERS_FORM_PLURAL = "plural"
 OPTION_ROBOT_COMPLETION_SECTION_HEADERS_FORM_SINGULAR = "singular"
 OPTION_ROBOT_COMPLETION_SECTION_HEADERS_FORM_BOTH = "both"
 
-
 # Options which must be set as environment variables.
-ENV_OPTION_ROBOT_LSP_DEBUG_MESSAGE_MATCHERS = "ROBOT_LSP_DEBUG_MESSAGE_MATCHERS"
-
-ENV_OPTION_ROBOT_LSP_DEBUG_PROCESS_ENVIRON = "ROBOT_LSP_DEBUG_PROCESS_ENVIRON"
-
 ENV_OPTION_ROBOT_DAP_TIMEOUT = "ROBOT_DAP_TIMEOUT"
