@@ -2,11 +2,11 @@ def complete(completion_context):
     """
     :param CompletionContext completion_context:
     """
-    from robotframework_ls.lsp import CompletionItemKind
-    from robotframework_ls.lsp import CompletionItem
-    from robotframework_ls.lsp import TextEdit
-    from robotframework_ls.lsp import Range
-    from robotframework_ls.lsp import Position
+    from robocode_ls_core.lsp import CompletionItemKind
+    from robocode_ls_core.lsp import CompletionItem
+    from robocode_ls_core.lsp import TextEdit
+    from robocode_ls_core.lsp import Range
+    from robocode_ls_core.lsp import Position
     from robotframework_ls.impl import text_utilities
     from robotframework_ls.impl.string_matcher import RobotStringMatcher
     from robotframework_ls.impl.robot_lsp_constants import (
