@@ -1,4 +1,4 @@
-from robotframework_ls import cache
+from robocode_ls_core.cache import instance_cache
 
 
 class IVariableFound(object):
@@ -30,9 +30,9 @@ class _VariableFound(object):
         self.variable_value = variable_value
 
     @property
-    @cache.instance_cache
+    @instance_cache
     def source(self):
-        from robotframework_ls import uris
+        from robocode_ls_core import uris
 
         return uris.to_fs_path(self.completion_context.doc.uri)
 
@@ -66,15 +66,15 @@ class _Collector(object):
         :param selection:
         :param token:
         """
-        from robotframework_ls.lsp import (
+        from robocode_ls_core.lsp import (
             CompletionItem,
             InsertTextFormat,
             Position,
             Range,
             TextEdit,
         )
-        from robotframework_ls.lsp import MarkupKind
-        from robotframework_ls.lsp import CompletionItemKind
+        from robocode_ls_core.lsp import MarkupKind
+        from robocode_ls_core.lsp import CompletionItemKind
 
         label = variable_found.variable_name
         text = label
