@@ -1,8 +1,6 @@
-from robotframework_ls import _utils
-from robotframework_ls.python_ls import PythonLanguageServer
+from robocode_ls_core.python_ls import PythonLanguageServer
 import threading
-import logging
-from robotframework_ls._utils import (
+from robocode_ls_core.basic import (
     overrides,
     log_and_silence_errors,
     kill_process_and_subprocesses,
@@ -15,13 +13,13 @@ from functools import partial
 import itertools
 import time
 from robotframework_ls.constants import DEFAULT_COMPLETIONS_TIMEOUT
-from robotframework_ls.robotframework_log import get_logger
+from robocode_ls_core.robotframework_log import get_logger
+from robocode_ls_core import basic
 
 
 log = get_logger(__name__)
 
 LINT_DEBOUNCE_S = 0.5  # 500 ms
-ROBOT_FILE_EXTENSIONS = (".robot", ".settings")
 _next_id = partial(next, itertools.count(0))
 
 
@@ -128,7 +126,7 @@ class _ServerApi(object):
                     from robotframework_ls.server_api.server__main__ import (
                         start_server_process,
                     )
-                    from robotframework_ls.jsonrpc.streams import (
+                    from robocode_ls_core.jsonrpc.streams import (
                         JsonRpcStreamWriter,
                         JsonRpcStreamReader,
                     )
@@ -302,11 +300,8 @@ class _ServerApi(object):
 
 class RobotFrameworkLanguageServer(PythonLanguageServer):
     def __init__(self, rx, tx):
-        from robotframework_ls.lsp import LSPMessages
-
         self._api = _ServerApi(self)
         PythonLanguageServer.__init__(self, rx, tx)
-        self._lsp_messages = LSPMessages(self._endpoint)
 
     @property
     def config(self):
@@ -325,7 +320,7 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
 
     @overrides(PythonLanguageServer.capabilities)
     def capabilities(self):
-        from robotframework_ls import lsp
+        from robocode_ls_core.lsp import TextDocumentSyncKind
 
         server_capabilities = {
             "codeActionProvider": False,
@@ -349,7 +344,7 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
             #     'triggerCharacters': ['(', ',', '=']
             # },
             "textDocumentSync": {
-                "change": lsp.TextDocumentSyncKind.INCREMENTAL,
+                "change": TextDocumentSyncKind.INCREMENTAL,
                 "save": {"includeText": False},
                 "openClose": True,
             },
@@ -447,7 +442,7 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
     # --- Customized implementation
 
     @overrides(PythonLanguageServer.lint)
-    @_utils.debounce(LINT_DEBOUNCE_S, keyed_by="doc_uri")
+    @basic.debounce(LINT_DEBOUNCE_S, keyed_by="doc_uri")
     def lint(self, doc_uri, is_saved):
         # Since we're debounced, the document may no longer be open
         try:
@@ -486,6 +481,7 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
     def m_text_document__completion(self, **kwargs):
         from robotframework_ls.impl.completion_context import CompletionContext
         from robotframework_ls.impl import section_completions
+        from robotframework_ls.impl import snippets_completions
 
         doc_uri = kwargs["textDocument"]["uri"]
         # Note: 0-based
@@ -503,6 +499,7 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
         message_matchers = []
         message_matchers.append(self._api.request_complete_all(doc_uri, line, col))
         completions.extend(section_completions.complete(ctx))
+        completions.extend(snippets_completions.complete(ctx))
 
         accepted_message_matchers = self._wait_for_message_matchers(message_matchers)
         for message_matcher in accepted_message_matchers:
