@@ -1,6 +1,6 @@
-from robotframework_ls.python_ls import PythonLanguageServer
-from robotframework_ls._utils import overrides
-from robotframework_ls.robotframework_log import get_logger
+from robocode_ls_core.python_ls import PythonLanguageServer
+from robocode_ls_core.basic import overrides
+from robocode_ls_core.robotframework_log import get_logger
 
 
 log = get_logger(__name__)
@@ -43,7 +43,7 @@ class RobotFrameworkServerApi(PythonLanguageServer):
         return self._version
 
     def _check_min_version(self, min_version):
-        from robotframework_ls._utils import check_min_version
+        from robocode_ls_core.basic import check_min_version
 
         version = self.m_version()
         return check_min_version(version, min_version)
@@ -62,7 +62,7 @@ class RobotFrameworkServerApi(PythonLanguageServer):
 
     def m_lint(self, doc_uri):
         if not self._check_min_version((3, 2)):
-            from robotframework_ls.lsp import Error
+            from robocode_ls_core.lsp import Error
 
             msg = (
                 "robotframework version (%s) too old for linting.\n"
@@ -122,8 +122,8 @@ class RobotFrameworkServerApi(PythonLanguageServer):
     def m_find_definition(self, doc_uri, line, col):
         from robotframework_ls.impl.find_definition import find_definition
         import os.path
-        from robotframework_ls.lsp import Location, Range
-        from robotframework_ls import uris
+        from robocode_ls_core.lsp import Location, Range
+        from robocode_ls_core import uris
 
         completion_context = self._create_completion_context(doc_uri, line, col)
         if completion_context is None:
@@ -163,7 +163,7 @@ class RobotFrameworkServerApi(PythonLanguageServer):
     def m_code_format(self, text_document, options):
         from robotframework_ls.impl.formatting import robot_source_format
         from robotframework_ls.impl.formatting import create_text_edit_from_diff
-        from robotframework_ls.lsp import TextDocumentItem
+        from robocode_ls_core.lsp import TextDocumentItem
 
         text_document_item = TextDocumentItem(**text_document)
         text = text_document_item.text
